==> kdeadmin-1.91.tar.bz2: kdeadmin-1.91/ksysctrl/ksysctrl/deventry.h <==
/*
 *  This file is part of the KDE System Control Tool,
 *  Copyright (C)1999 Thorsten Westheider <twesthei@physik.uni-bielefeld.de>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 ****************************************************************************/

#ifndef __DEVENTRY_H
#define __DEVENTRY_H

#include <qlistview.h>

#include "device.h"


class DeviceEntry : public QListViewItem
{
  public:
  
    DeviceEntry(QListViewItem *parent, Device *);   
    DeviceEntry(QListView *parent, Device::baseclass, const char *classname);   
    ~DeviceEntry() {}
    
    void	       setConflict(bool b)     { _conflict = b;     } 
    
    bool	       conflict()        const { return _conflict;  }
    Device             *device()               { return _device;    }
    Device::baseclass  deviceBaseClass() const { return _baseclass; }

  private:
  
    Device             *_device;
    Device::baseclass  _baseclass;  
    
    bool               _conflict;
};


#endif

==> kdeadmin-2.1.1.tar.bz2: kdeadmin-2.1.1/ksysctrl/ksysctrl/deventry.h <==
/*
 *  This file is part of the KDE System Control Tool,
 *  Copyright (C)1999 Thorsten Westheider <twesthei@physik.uni-bielefeld.de>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 ****************************************************************************/

#ifndef __DEVENTRY_H
#define __DEVENTRY_H

#include <qlistview.h>

#include "device.h"


class DeviceEntry : public QListViewItem
{
  public:
  
    DeviceEntry(QListViewItem *parent, Device *);   
    DeviceEntry(QListView *parent, Device::baseclass, const QString & classname);   
    ~DeviceEntry() {}
    
    void	       setConflict(bool b)     { _conflict = b;     } 
    
    bool	       conflict()        const { return _conflict;  }
    Device             *device()               { return _device;    }
    Device::baseclass  deviceBaseClass() const { return _baseclass; }

  private:
  
    Device             *_device;
    Device::baseclass  _baseclass;  
    
    bool               _conflict;
};


#endif
